<?php
function _rebuildThumb(&$tof,$vars) {
	require("actions/thumb.php");
	createThumb(
		$tof,
		$tof->ct->getPicture($vars['PictureID']),
		true);
}
?>